@@ -83,11 +83,13 @@ static PetscErrorCode EPSSetUp_Power(EPS eps)
   void           *ctx;
 
   PetscFunctionBegin;
-  if (eps->ncv!=PETSC_DEFAULT) {
+  EPSCheckNotStructured(eps);
+  if (eps->nev==0) eps->nev = 1;
+  if (eps->ncv!=PETSC_DETERMINE) {
     PetscCheck(eps->ncv>=eps->nev,PetscObjectComm((PetscObject)eps),PETSC_ERR_USER_INPUT,"The value of ncv must be at least nev");
   } else eps->ncv = eps->nev;
-  if (eps->mpd!=PETSC_DEFAULT) PetscCall(PetscInfo(eps,"Warning: parameter mpd ignored\n"));
-  if (eps->max_it==PETSC_DEFAULT) {
+  if (eps->mpd!=PETSC_DETERMINE) PetscCall(PetscInfo(eps,"Warning: parameter mpd ignored\n"));
+  if (eps->max_it==PETSC_DETERMINE) {
     /* SNES will directly return the solution for us, and we need to do only one iteration */
     if (power->nonlinear && power->update) eps->max_it = 1;
     else eps->max_it = PetscMax(1000*eps->nev,100*eps->n);
@@ -100,7 +102,7 @@ static PetscErrorCode EPSSetUp_Power(EPS eps)
     PetscCall(STGetMatMode(eps->st,&mode));
     PetscCheck(mode!=ST_MATMODE_INPLACE,PetscObjectComm((PetscObject)eps),PETSC_ERR_SUP,"ST matrix mode inplace does not work with variable shifts");
   }
-  EPSCheckUnsupported(eps,EPS_FEATURE_BALANCE | EPS_FEATURE_ARBITRARY | EPS_FEATURE_REGION | EPS_FEATURE_CONVERGENCE);
+  EPSCheckUnsupported(eps,EPS_FEATURE_BALANCE | EPS_FEATURE_ARBITRARY | EPS_FEATURE_REGION | EPS_FEATURE_CONVERGENCE | EPS_FEATURE_THRESHOLD);
   EPSCheckIgnored(eps,EPS_FEATURE_EXTRACTION);
   PetscCall(EPSAllocateSolution(eps,0));
   PetscCall(EPS_SetInnerProduct(eps));
@@ -117,7 +119,7 @@ static PetscErrorCode EPSSetUp_Power(EPS eps)
 
     /* For nonlinear solver (Newton), we should scale the initial vector back.
        The initial vector will be scaled in EPSSetUp. */
-    if (eps->IS) PetscCall(VecNorm((eps->IS)[0],NORM_2,&power->norm0));
+    if (eps->IS) PetscCall(VecNorm(eps->IS[0],NORM_2,&power->norm0));
 
     PetscCall(EPSGetOperators(eps,&A,&B));
 
@@ -203,7 +205,7 @@ static PetscErrorCode FirstNonzeroIdx(Vec x,PetscInt *idx,PetscMPIInt *p)
   }
   PetscCall(VecRestoreArrayRead(x,&xx));
   if (i==last) i=N;
-  PetscCall(MPIU_Allreduce(&i,idx,1,MPIU_INT,MPI_MIN,PetscObjectComm((PetscObject)x)));
+  PetscCallMPI(MPIU_Allreduce(&i,idx,1,MPIU_INT,MPI_MIN,PetscObjectComm((PetscObject)x)));
   PetscCheck(*idx!=N,PetscObjectComm((PetscObject)x),PETSC_ERR_PLIB,"Zero vector found");
   PetscCall(VecGetLayout(x,&map));
   PetscCall(PetscLayoutFindOwner(map,*idx,p));
@@ -727,7 +729,7 @@ static PetscErrorCode EPSBackTransform_Power(EPS eps)
   PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-static PetscErrorCode EPSSetFromOptions_Power(EPS eps,PetscOptionItems *PetscOptionsObject)
+static PetscErrorCode EPSSetFromOptions_Power(EPS eps,PetscOptionItems PetscOptionsObject)
 {
   EPS_POWER         *power = (EPS_POWER*)eps->data;
   PetscBool         flg,val;
